================================
Review Board 1.6.5 Release Notes
================================

**Release date**: March 30, 2012


Important Updates
=================

* Django 1.4 recently released, which Review Board 1.6.x is not compatible
  with. We now hard-code 1.3.1 as a requirement.


Web API Changes
===============

* Fixed a breakage when querying for diff comments as an anonymous user.
  (:bug:`2488`)


Bug Fixes
=========

* Support parsing Git diffs with moved file information.

  Git diffs with moved file information wasn't being parsed right. This
  led to errors when attempting to upload such diffs. 

  Patch by Dave Druska.

* Fixed rendering issues on Internet Explorer 8, 9, and 10.

  Current versions of IE don't display correctly, as they run in
  IE Compatibility Mode. We now turn that off. Patch by Ben Allen.

* The source tarball now contains the documentation database, needed to
  generate docs. (:bug:`2141`)


Contributors
============

* Ben Allen
* Christian Hammond
* Dave Druska
* David Trowbridge
